@@ -17,13 +17,11 @@ from curses import KEY_F5
 from totui_selenium.totui_selenium import SeleniumTradeOgre
 from tradeogre_api.tradeogre_api import TradeOgreAPI
 
-
- 
-
 BASEDIR = os.path.join(os.path.expanduser('~'), '.totui')
 CONFFILE = os.path.join(BASEDIR, 'config.ini')
+COINSFILE = os.path.join(BASEDIR, 'coins.list')
 CONFIG = configparser.ConfigParser()
-TOTUIVERSION = "TOTUI v1.7.3"
+TOTUIVERSION = "TOTUI v1.7.4"
 
 def read_configuration(confpath):
     """Read the configuration file at given path."""
@@ -32,12 +30,16 @@ def read_configuration(confpath):
     if os.path.isdir(BASEDIR):
         if not os.path.isfile(confpath):
             defaultconf = pkg_resources.resource_filename(__name__, 'config.ini')
+            defaultcoins = pkg_resources.resource_filename(__name__, 'coins.list')
             shutil.copyfile(defaultconf, CONFFILE)
+            shutil.copyfile(defaultcoins, COINSFILE)
 
     else:
         os.mkdir(BASEDIR)
         defaultconf = pkg_resources.resource_filename(__name__, 'config.ini')
+        defaultcoins = pkg_resources.resource_filename(__name__, 'coins.list')
         shutil.copyfile(defaultconf, CONFFILE)
+        shutil.copyfile(defaultcoins, COINSFILE)
         
     CONFIG.read(confpath)
     return CONFIG
